@@ -12,6 +12,7 @@ from acme import messages
 
 from certbot import achallenges
 from certbot import errors
+from certbot.tests import util as certbot_test_util
 
 from certbot_nginx import obj
 from certbot_nginx import parser
@@ -44,8 +45,6 @@ class NginxConfiguratorTest(util.NginxTest):
     def test_prepare(self):
         self.assertEqual((1, 6, 2), self.config.version)
         self.assertEqual(8, len(self.config.parser.parsed))
-        # ensure we successfully parsed a file for ssl_options
-        self.assertTrue(self.config.parser.loc["ssl_options"])
 
     @mock.patch("certbot_nginx.configurator.util.exe_exists")
     @mock.patch("certbot_nginx.configurator.subprocess.Popen")
@@ -65,6 +64,23 @@ class NginxConfiguratorTest(util.NginxTest):
         self.config.prepare()
         self.assertEqual((1, 6, 2), self.config.version)
 
+    def test_prepare_locked(self):
+        server_root = self.config.conf("server-root")
+        self.config.config_test = mock.Mock()
+        os.remove(os.path.join(server_root, ".certbot.lock"))
+        certbot_test_util.lock_and_call(self._test_prepare_locked, server_root)
+
+    @mock.patch("certbot_nginx.configurator.util.exe_exists")
+    def _test_prepare_locked(self, unused_exe_exists):
+        try:
+            self.config.prepare()
+        except errors.PluginError as err:
+            err_msg = str(err)
+            self.assertTrue("lock" in err_msg)
+            self.assertTrue(self.config.conf("server-root") in err_msg)
+        else:  # pragma: no cover
+            self.fail("Exception wasn't raised!")
+
     @mock.patch("certbot_nginx.configurator.socket.gethostbyaddr")
     def test_get_all_names(self, mock_gethostbyaddr):
         mock_gethostbyaddr.return_value = ('155.225.50.69.nephoscale.net', [], [])
@@ -207,8 +223,8 @@ class NginxConfiguratorTest(util.NginxTest):
 
                             ['listen', '5001', 'ssl'],
                             ['ssl_certificate', 'example/fullchain.pem'],
-                            ['ssl_certificate_key', 'example/key.pem']] +
-                            util.filter_comments(self.config.parser.loc["ssl_options"])
+                            ['ssl_certificate_key', 'example/key.pem'],
+                            ['include', self.config.mod_ssl_conf]]
                             ]],
                          parsed_example_conf)
         self.assertEqual([['server_name', 'somename', 'alias', 'another.alias']],
@@ -225,8 +241,8 @@ class NginxConfiguratorTest(util.NginxTest):
                 ['index', 'index.html', 'index.htm']]],
               ['listen', '5001', 'ssl'],
               ['ssl_certificate', '/etc/nginx/fullchain.pem'],
-              ['ssl_certificate_key', '/etc/nginx/key.pem']] +
-             util.filter_comments(self.config.parser.loc["ssl_options"])
+              ['ssl_certificate_key', '/etc/nginx/key.pem'],
+              ['include', self.config.mod_ssl_conf]]
             ],
             2))
 
@@ -249,8 +265,8 @@ class NginxConfiguratorTest(util.NginxTest):
                            ['listen', '80'],
                            ['listen', '5001', 'ssl'],
                            ['ssl_certificate', 'summer/fullchain.pem'],
-                           ['ssl_certificate_key', 'summer/key.pem']] +
-                           util.filter_comments(self.config.parser.loc["ssl_options"])
+                           ['ssl_certificate_key', 'summer/key.pem'],
+                           ['include', self.config.mod_ssl_conf]]
                            ],
                          parsed_migration_conf[0])
 
